entity_store
library
Classes
-
CountOptions
-
-
DeleteEvent<Id, E extends Entity<Id>>
-
-
DeleteOptions
-
-
Entity<Id>
-
An abstract class representing an entity with a unique identifier.
-
EntityChange<E>
-
-
EntityCreatedEvent<Id, E extends Entity<Id>>
-
-
EntityDeletedEvent<Id, E extends Entity<Id>>
-
-
EntityEvent<Id, E extends Entity<Id>>
-
-
EntityEventListener
-
-
EntityMap<Id, E extends Entity<Id>>
-
The EntityMap class holds multiple Entities and provides Immutable Entity collection operations.
-
EntityStore
-
-
EntityStoreController
-
-
EntityStoreCountOptions
-
-
EntityStoreDebugger
-
-
EntityStoreDeleteOptions
-
-
EntityStoreFindAllOptions
-
-
EntityStoreFindByIdOptions
-
-
EntityStoreFindOneOptions
-
-
EntityStorePrintDebugger
-
-
EntityStoreQueryUpsertOptions
-
-
EntityStoreRepository<Id, E extends Entity<Id>>
-
-
EntityStoreSaveOptions
-
-
EntityStoreUpsertOptions
-
-
EntityUpdatedEvent<Id, E extends Entity<Id>>
-
-
FetchPolicyOptions
-
-
FindAllOptions
-
-
FindByIdOptions
-
-
FindOneOptions
-
-
GetEvent<Id, E extends Entity<Id>>
-
-
Id
-
-
IDataSourceHandler<Id, E extends Entity<Id>>
-
A handler for a data source.
-
InMemoryDataSourceHandler<Id, E extends Entity<Id>>
-
-
IPersistenceEventHandler
-
-
IRepositoryQuery<Id, E extends Entity<Id>>
-
-
IUpdatable<T>
-
-
ListEvent<Id, E extends Entity<Id>>
-
-
ObserveAllOptions
-
-
ObserveByIdOptions
-
-
PersistenceEvent<Id, E extends Entity<Id>>
-
-
QueryUpsertOptions
-
-
Repository<Id, E extends Entity<Id>>
-
An interface for a repository that handles CRUD operations for entities.
-
RepositoryFilter
-
-
RepositorySort
-
-
SaveEvent<Id, E extends Entity<Id>>
-
-
SaveOptions
-
-
StorageCountOptions
-
-
StorageDeleteOptions
-
-
StorageFindAllOptions
-
-
StorageFindByIdOptions
-
-
StorageFindOneOptions
-
-
StorageQueryUpsertOptions
-
-
StorageRepository<Id, E extends Entity<Id>>
-
The StorageRepository is a repository that handles a generic storage as a data source.
-
StorageRepositoryQuery<Id, E extends Entity<Id>>
-
-
StorageSaveOptions
-
-
StorageUpsertOptions
-
-
TransactionContext
-
-
TransactionOptions
-
-
TransactionRunner<TTransactionContext extends TransactionContext>
-
-
UpsertOptions
-
-
UseTransactionOptions
-
Typedefs
-
Updater<T>
= T Function(T prev)
-